contexttools.TempoMark
======================

.. inheritance-diagram:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark
   :private-bases:

.. autoclass:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.effective_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.format

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_imprecise

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.quarters_per_minute

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.target_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.duration

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.textual_indication

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.units_per_minute

Methods
-------

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.attach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.detach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_tempo_mark_token

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__add__

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__div__

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__eq__

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__mul__

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__str__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__sub__
